==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/importexport/kotlin/inputs/ReturnAddressArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.importexport.kotlin.inputs

import com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the return address information for the job.
 * @property city The city name to use when returning the drives.
 * @property countryOrRegion The country or region to use when returning the drives.
 * @property email Email address of the recipient of the returned drives.
 * @property phone Phone number of the recipient of the returned drives.
 * @property postalCode The postal code to use when returning the drives.
 * @property recipientName The name of the recipient who will receive the hard drives when they are returned.
 * @property stateOrProvince The state or province to use when returning the drives.
 * @property streetAddress1 The first line of the street address to use when returning the drives.
 * @property streetAddress2 The second line of the street address to use when returning the drives.
 */
public data class ReturnAddressArgs(
    public val city: Output<String>,
    public val countryOrRegion: Output<String>,
    public val email: Output<String>,
    public val phone: Output<String>,
    public val postalCode: Output<String>,
    public val recipientName: Output<String>,
    public val stateOrProvince: Output<String>? = null,
    public val streetAddress1: Output<String>,
    public val streetAddress2: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs> {
    override fun toJava(): com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs =
        com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs.builder()
            .city(city.applyValue({ args0 -> args0 }))
            .countryOrRegion(countryOrRegion.applyValue({ args0 -> args0 }))
            .email(email.applyValue({ args0 -> args0 }))
            .phone(phone.applyValue({ args0 -> args0 }))
            .postalCode(postalCode.applyValue({ args0 -> args0 }))
            .recipientName(recipientName.applyValue({ args0 -> args0 }))
            .stateOrProvince(stateOrProvince?.applyValue({ args0 -> args0 }))
            .streetAddress1(streetAddress1.applyValue({ args0 -> args0 }))
            .streetAddress2(streetAddress2?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ReturnAddressArgs].
 */
@PulumiTagMarker
public class ReturnAddressArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var countryOrRegion: Output<String>? = null

    private var email: Output<String>? = null

    private var phone: Output<String>? = null

    private var postalCode: Output<String>? = null

    private var recipientName: Output<String>? = null

    private var stateOrProvince: Output<String>? = null

    private var streetAddress1: Output<String>? = null

    private var streetAddress2: Output<String>? = null

    /**
     * @param value The city name to use when returning the drives.
     */
    @JvmName("wbvuhilspcckjerg")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value The country or region to use when returning the drives.
     */
    @JvmName("fffntpfsvkqtonos")
    public suspend fun countryOrRegion(`value`: Output<String>) {
        this.countryOrRegion = value
    }

    /**
     * @param value Email address of the recipient of the returned drives.
     */
    @JvmName("agnsecuscxdtsskr")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value Phone number of the recipient of the returned drives.
     */
    @JvmName("ejgpfexupoyqpsxf")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The postal code to use when returning the drives.
     */
    @JvmName("rdcpmgrbbtabnwfx")
    public suspend fun postalCode(`value`: Output<String>) {
        this.postalCode = value
    }

    /**
     * @param value The name of the recipient who will receive the hard drives when they are returned.
     */
    @JvmName("knwqybemxmqbltoi")
    public suspend fun recipientName(`value`: Output<String>) {
        this.recipientName = value
    }

    /**
     * @param value The state or province to use when returning the drives.
     */
    @JvmName("otrbjtierxrvncgs")
    public suspend fun stateOrProvince(`value`: Output<String>) {
        this.stateOrProvince = value
    }

    /**
     * @param value The first line of the street address to use when returning the drives.
     */
    @JvmName("dmaufoiufmqovhvn")
    public suspend fun streetAddress1(`value`: Output<String>) {
        this.streetAddress1 = value
    }

    /**
     * @param value The second line of the street address to use when returning the drives.
     */
    @JvmName("bioistijykvtnbem")
    public suspend fun streetAddress2(`value`: Output<String>) {
        this.streetAddress2 = value
    }

    /**
     * @param value The city name to use when returning the drives.
     */
    @JvmName("bfdkraqmfltsnnai")
    public suspend fun city(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value The country or region to use when returning the drives.
     */
    @JvmName("vjlanlrtegqgqxkx")
    public suspend fun countryOrRegion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.countryOrRegion = mapped
    }

    /**
     * @param value Email address of the recipient of the returned drives.
     */
    @JvmName("exesfmfikislweun")
    public suspend fun email(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value Phone number of the recipient of the returned drives.
     */
    @JvmName("ajkmhggeeowmjwvd")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    /**
     * @param value The postal code to use when returning the drives.
     */
    @JvmName("hlptdooogdcxgbsj")
    public suspend fun postalCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.postalCode = mapped
    }

    /**
     * @param value The name of the recipient who will receive the hard drives when they are returned.
     */
    @JvmName("fwojjihotbvonatx")
    public suspend fun recipientName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recipientName = mapped
    }

    /**
     * @param value The state or province to use when returning the drives.
     */
    @JvmName("xwhuuptxbscbepvs")
    public suspend fun stateOrProvince(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stateOrProvince = mapped
    }

    /**
     * @param value The first line of the street address to use when returning the drives.
     */
    @JvmName("oilqydqqxrfihgwm")
    public suspend fun streetAddress1(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.streetAddress1 = mapped
    }

    /**
     * @param value The second line of the street address to use when returning the drives.
     */
    @JvmName("isktircelnpvvkfe")
    public suspend fun streetAddress2(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.streetAddress2 = mapped
    }

    internal fun build(): ReturnAddressArgs = ReturnAddressArgs(
        city = city ?: throw PulumiNullFieldException("city"),
        countryOrRegion = countryOrRegion ?: throw PulumiNullFieldException("countryOrRegion"),
        email = email ?: throw PulumiNullFieldException("email"),
        phone = phone ?: throw PulumiNullFieldException("phone"),
        postalCode = postalCode ?: throw PulumiNullFieldException("postalCode"),
        recipientName = recipientName ?: throw PulumiNullFieldException("recipientName"),
        stateOrProvince = stateOrProvince,
        streetAddress1 = streetAddress1 ?: throw PulumiNullFieldException("streetAddress1"),
        streetAddress2 = streetAddress2,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/importexport/kotlin/inputs/ReturnAddressArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.importexport.kotlin.inputs

import com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the return address information for the job.
 * @property city The city name to use when returning the drives.
 * @property countryOrRegion The country or region to use when returning the drives.
 * @property email Email address of the recipient of the returned drives.
 * @property phone Phone number of the recipient of the returned drives.
 * @property postalCode The postal code to use when returning the drives.
 * @property recipientName The name of the recipient who will receive the hard drives when they are returned.
 * @property stateOrProvince The state or province to use when returning the drives.
 * @property streetAddress1 The first line of the street address to use when returning the drives.
 * @property streetAddress2 The second line of the street address to use when returning the drives.
 */
public data class ReturnAddressArgs(
    public val city: Output<String>,
    public val countryOrRegion: Output<String>,
    public val email: Output<String>,
    public val phone: Output<String>,
    public val postalCode: Output<String>,
    public val recipientName: Output<String>,
    public val stateOrProvince: Output<String>? = null,
    public val streetAddress1: Output<String>,
    public val streetAddress2: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs> {
    override fun toJava(): com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs =
        com.pulumi.azurenative.importexport.inputs.ReturnAddressArgs.builder()
            .city(city.applyValue({ args0 -> args0 }))
            .countryOrRegion(countryOrRegion.applyValue({ args0 -> args0 }))
            .email(email.applyValue({ args0 -> args0 }))
            .phone(phone.applyValue({ args0 -> args0 }))
            .postalCode(postalCode.applyValue({ args0 -> args0 }))
            .recipientName(recipientName.applyValue({ args0 -> args0 }))
            .stateOrProvince(stateOrProvince?.applyValue({ args0 -> args0 }))
            .streetAddress1(streetAddress1.applyValue({ args0 -> args0 }))
            .streetAddress2(streetAddress2?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ReturnAddressArgs].
 */
@PulumiTagMarker
public class ReturnAddressArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var countryOrRegion: Output<String>? = null

    private var email: Output<String>? = null

    private var phone: Output<String>? = null

    private var postalCode: Output<String>? = null

    private var recipientName: Output<String>? = null

    private var stateOrProvince: Output<String>? = null

    private var streetAddress1: Output<String>? = null

    private var streetAddress2: Output<String>? = null

    /**
     * @param value The city name to use when returning the drives.
     */
    @JvmName("mwmaxhvnhcedidkx")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value The country or region to use when returning the drives.
     */
    @JvmName("yipkbonarjwdsawo")
    public suspend fun countryOrRegion(`value`: Output<String>) {
        this.countryOrRegion = value
    }

    /**
     * @param value Email address of the recipient of the returned drives.
     */
    @JvmName("becxspfipdcpbpdg")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value Phone number of the recipient of the returned drives.
     */
    @JvmName("pknlekinglvvqvdj")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The postal code to use when returning the drives.
     */
    @JvmName("reprhdcqcxcbjopn")
    public suspend fun postalCode(`value`: Output<String>) {
        this.postalCode = value
    }

    /**
     * @param value The name of the recipient who will receive the hard drives when they are returned.
     */
    @JvmName("aribrahwkdyxsjop")
    public suspend fun recipientName(`value`: Output<String>) {
        this.recipientName = value
    }

    /**
     * @param value The state or province to use when returning the drives.
     */
    @JvmName("ckknnflrosowjhhk")
    public suspend fun stateOrProvince(`value`: Output<String>) {
        this.stateOrProvince = value
    }

    /**
     * @param value The first line of the street address to use when returning the drives.
     */
    @JvmName("syckgwirioduldbv")
    public suspend fun streetAddress1(`value`: Output<String>) {
        this.streetAddress1 = value
    }

    /**
     * @param value The second line of the street address to use when returning the drives.
     */
    @JvmName("qxyiraydugplimtg")
    public suspend fun streetAddress2(`value`: Output<String>) {
        this.streetAddress2 = value
    }

    /**
     * @param value The city name to use when returning the drives.
     */
    @JvmName("fbakjoyoskxtxokt")
    public suspend fun city(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value The country or region to use when returning the drives.
     */
    @JvmName("rvlisustpwdgwrbn")
    public suspend fun countryOrRegion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.countryOrRegion = mapped
    }

    /**
     * @param value Email address of the recipient of the returned drives.
     */
    @JvmName("mahooaeybbxydonb")
    public suspend fun email(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value Phone number of the recipient of the returned drives.
     */
    @JvmName("frebeybdrdpjhjlv")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    /**
     * @param value The postal code to use when returning the drives.
     */
    @JvmName("jujakvhsgrvjaybw")
    public suspend fun postalCode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.postalCode = mapped
    }

    /**
     * @param value The name of the recipient who will receive the hard drives when they are returned.
     */
    @JvmName("cpkpalmwqahsxked")
    public suspend fun recipientName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recipientName = mapped
    }

    /**
     * @param value The state or province to use when returning the drives.
     */
    @JvmName("drxstdmoiifupeiq")
    public suspend fun stateOrProvince(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stateOrProvince = mapped
    }

    /**
     * @param value The first line of the street address to use when returning the drives.
     */
    @JvmName("qxyyjvkfhbqltkjo")
    public suspend fun streetAddress1(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.streetAddress1 = mapped
    }

    /**
     * @param value The second line of the street address to use when returning the drives.
     */
    @JvmName("bscbkuimulpdqiit")
    public suspend fun streetAddress2(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.streetAddress2 = mapped
    }

    internal fun build(): ReturnAddressArgs = ReturnAddressArgs(
        city = city ?: throw PulumiNullFieldException("city"),
        countryOrRegion = countryOrRegion ?: throw PulumiNullFieldException("countryOrRegion"),
        email = email ?: throw PulumiNullFieldException("email"),
        phone = phone ?: throw PulumiNullFieldException("phone"),
        postalCode = postalCode ?: throw PulumiNullFieldException("postalCode"),
        recipientName = recipientName ?: throw PulumiNullFieldException("recipientName"),
        stateOrProvince = stateOrProvince,
        streetAddress1 = streetAddress1 ?: throw PulumiNullFieldException("streetAddress1"),
        streetAddress2 = streetAddress2,
    )
}
